@@ -1,9 +1,14 @@
 # -*- coding: utf-8 -*-
 
-from PIL import Image, ImageDraw, ImageFont
+from PIL import Image, ImageDraw, ImageFont, ImageOps
 import os
 from hashlib import md5
 
+def color2rgba(color):
+    assert(color[0]=='#')
+    return (int(color[1:3],16),int(color[3:5],16),int(color[5:7],16),0)
+
+
 class TextImage:
 
     text='test'
@@ -36,6 +41,7 @@ class TextImage:
         if kw.has_key('force'): self.force=kw['force']
         if kw.has_key('padding'): self.padding=kw['padding'] 
         if kw.has_key('type'): self.type=kw['type'].lower()
+
         if self.debug: self.force=self.debug=True
 
         assert(os.path.exists(self.font))
@@ -69,8 +75,7 @@ class TextImage:
     def init_image(self):
         if self.color[0] != '#': self.color='#000000'
         if self.bgcol[0] != '#': self.bgcol='#ffffff'
-        self.image = Image.new(mode='RGBA', size=(self.width, self.height), color=self.bgcol)
-        self.image.info['quality'] = 100
+        self.image = Image.new(mode='RGBA', size=(self.width, self.height), color=color2rgba(self.bgcol))
 
     def get_left(self, linewidth):
         x = 0
@@ -90,6 +95,7 @@ class TextImage:
     def finalize(self):
         if self.type=='gif':
             self.image = self.image.convert('RGB').convert('P', palette=Image.ADAPTIVE)
+        self.image = ImageOps.crop(self.image,border=1)
         self.image.save(self.path, self.type.upper(), quality=100)
 
     def getPath(self):
